@@ -90,7 +90,6 @@ OC.L10N.register(
     "Additional settings" : "Plia agordo",
     "You need to enter details of an existing account." : "Vi entajpu detalojn pri ekzistanta konto.",
     "Oracle connection could not be established" : "Konekto al Oracle ne povis stariĝi",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "MacOS X ne estas subtenata kaj %s ne bone funkcios ĉe ĝi. Uzu ĝin je via risko!",
     "For the best results, please consider using a GNU/Linux server instead." : "Por pli bona funkciado, bv. pripensi uzi GNU-Linuksan servilon anstataŭe.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Ŝajnas, ke tiu servilo %s uzas 32-bitan PHP-version, kaj ke la agordo „open_basedir“ ekzistas. Tio kaŭzos problemojn pri dosieroj pli grandaj ol 4 GB, kaj do estas tre malrekomendita.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Bv. forigi la agordon „open_basedir“ de via php.ini, aŭ uzu 64-bitan version de PHP.",
@@ -98,14 +97,7 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Kunhava interna servo %s devas realigi la interfacon „OCP\\Share_Backend“",
     "Sharing backend %s not found" : "Kunhava interna servo %s ne troviĝas",
     "Sharing backend for %s not found" : "Kunhava interna servo por %s ne troviĝas",
-    "%1$s shared »%2$s« with you" : "%1$s kunhavigis „%2$s“ kun vi",
-    "%1$s shared »%2$s« with you." : "%1$s kunhavigis „%2$s“ kun vi.",
-    "Click the button below to open it." : "Alklaku la butonon ĉi-sube por malfermi ĝin.",
-    "Open »%s«" : "Malfermi „%s“",
     "%1$s via %2$s" : "%1$s pere de %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s kunhavigis „%2$s“ kun vi kaj volas aldoni:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s kunhavigis „%2$s“ kun vi kaj volas aldoni",
-    "»%s« added a note to a file shared with you" : "„%s“ aldonis noton al dosiero kunhavigita kun vi",
     "Unknown share type" : "Nekonata kunhava tipo",
     "You are not allowed to share %s" : "Vi ne permesatas kunhavigi %s",
     "Cannot increase permissions of %s" : "Ne eblas pliigi permesojn de %s",
@@ -161,7 +153,6 @@ OC.L10N.register(
     "Login canceled by app" : "Ensaluto estis nuligita de aplikaĵo",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "La aplikaĵo „%1$s“ ne instaliĝas, ĉar la jenaj dependecoj ne plenumiĝas: %2$s",
     "a safe home for all your data" : "sekura hejmo por ĉiuj viaj datumoj",
-    "File is currently busy, please try again later" : "La dosiero estas nun okupita, bv. reprovi poste",
     "Application is not enabled" : "La aplikaĵo ne estas ŝaltita",
     "Authentication error" : "Aŭtentiga eraro",
     "Token expired. Please reload page." : "Ĵetono eksvalidiĝis. Bonvolu reŝargi la paĝon.",
@@ -186,30 +177,10 @@ OC.L10N.register(
     "Storage connection error. %s" : "Konekta eraro al konservejo. %s",
     "Storage is temporarily not available" : "Konservejo provizore ne disponeblas",
     "Storage connection timeout. %s" : "Konekto al konservejo eltempiĝis. %s",
+    "Images" : "Bildoj",
+    "Text" : "Teksto",
     "Summary" : "Resumo",
     "Translate" : "Traduku",
-    "Education Edition" : "Eldono por edukado",
-    "Logged in user must be an admin or sub admin" : "La ensalutanta uzanto estu administranto aŭ subadministranto",
-    "Logged in user must be an admin" : "La ensalutanta uzanto estu administranto",
-    "File name is a reserved word" : "Dosiernomo estas rezervita vorto",
-    "File name contains at least one invalid character" : "Dosiernomo enhavas almenaŭ unu nevalidan signon",
-    "File name is too long" : "La dosiernomo estas tro longa",
-    "Help" : "Helpo",
-    "Users" : "Uzantoj",
-    "Unknown user" : "Nekonata uzanto",
-    "MySQL username and/or password not valid" : "La uzantnomo kaj/aŭ pasvorto de MySQL ne estas valida",
-    "Oracle username and/or password not valid" : "La uzantnomo kaj/aŭ la pasvorto de Oracle ne estas valida",
-    "PostgreSQL username and/or password not valid" : "La uzantnomo aŭ la pasvorto de PostgreSQL ne validas",
-    "Set an admin username." : "Agordi uzantnomon de administranto.",
-    "Sharing %s failed, because this item is already shared with user %s" : "Kunhavigo de %s malsukcesis, ĉar la ero jam kunhaviĝis kun %s",
-    "The username is already being used" : "La uzantnomo jam estas uzata",
-    "Could not create user" : "Ne povis krei uzanton",
-    "A valid username must be provided" : "Valida uzantnomo devas esti provizita",
-    "Username contains whitespace at the beginning or at the end" : "Uzantnomo enhavas spaceton ĉe la komenco aŭ la fino",
-    "Username must not consist of dots only" : "Uzantnomo ne povas enhavi nur punktojn",
-    "Username is invalid because files already exist for this user" : "La uzantnomo ne estas valida pro dosieroj por la uzanto jam ekzistas",
-    "User disabled" : "Uzanto malebligita",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Bv. ŝanĝi la permesojn al 0770, tiel la dosierujo ne listigeblas de aliaj uzantoj.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Certigu, ke estas dosiero nomata „.ocdata“ en la radiko de la dosierujo de datumoj."
+    "File is currently busy, please try again later" : "La dosiero estas nun okupita, bv. reprovi poste"
 },
 "nplurals=2; plural=(n != 1);");
