@@ -52,29 +52,34 @@ OC.L10N.register(
     "Avatar image is not square" : "Сликата за Аватар не е квадратна",
     "Files" : "Датотеки",
     "View profile" : "Прегледај профил",
+    "_%nh_::_%nh_" : ["%nч","%nч"],
+    "_%nm_::_%nm_" : ["%nм","%nм"],
     "Local time: %s" : "Локално време: %s",
     "today" : "денес",
     "tomorrow" : "утре",
     "yesterday" : "вчера",
-    "_in %n day_::_in %n days_" : ["за 1 ден","за %n дена"],
-    "_%n day ago_::_%n days ago_" : ["пред 1 ден","пред %n дена"],
+    "_in %n day_::_in %n days_" : ["за %n ден","за %n дена"],
+    "_%n day ago_::_%n days ago_" : ["пред %n ден","пред %n дена"],
     "next month" : "следниот месец",
     "last month" : "предходниот месец",
     "_in %n month_::_in %n months_" : ["за %n месец","за %n месеца"],
     "_%n month ago_::_%n months ago_" : ["пред %n месец","пред %n месеци"],
     "next year" : "следниот месец",
     "last year" : "предходната година",
-    "_in %n year_::_in %n years_" : ["за 1 година","за %n години"],
-    "_%n year ago_::_%n years ago_" : ["пред 1 година","пред %n години"],
-    "_in %n hour_::_in %n hours_" : ["за 1 час","за %n часа"],
-    "_%n hour ago_::_%n hours ago_" : ["пред 1 час","пред %n часа"],
-    "_in %n minute_::_in %n minutes_" : ["за 1 минута","за %n минути"],
-    "_%n minute ago_::_%n minutes ago_" : ["пред 1 минута","пред %n минути"],
+    "_in %n year_::_in %n years_" : ["за %n година","за %n години"],
+    "_%n year ago_::_%n years ago_" : ["пред %n година","пред %n години"],
+    "_in %n hour_::_in %n hours_" : ["за %n час","за %n часа"],
+    "_%n hour ago_::_%n hours ago_" : ["пред %n час","пред %n часа"],
+    "_in %n minute_::_in %n minutes_" : ["за %n минута","за %n минути"],
+    "_%n minute ago_::_%n minutes ago_" : ["пред %n минута","пред %n минути"],
     "in a few seconds" : "за неколку секунди",
     "seconds ago" : "пред неколку секунди",
     "Empty file" : "Празна датотека",
     "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модул со ИД: %s не постои. Овозможете го во параметрите на апликациите или контактирајте администратор.",
     "Dot files are not allowed" : "Датотеки само со точки не се дозволени",
+    "%1$s (renamed)" : "%1$s (преименувано)",
+    "renamed file" : "преименувана датотека",
+    "Filenames must not end with \"%1$s\"." : "Името неможе да завршува со \"%1$s\".",
     "File already exists" : "Датотека веќе постои",
     "Invalid path" : "Невалидна патека",
     "Failed to create file from template" : "Неуспешно креирање на датотека од шаблон",
@@ -107,14 +112,12 @@ OC.L10N.register(
     "About" : "За",
     "Display name" : "Име и презиме",
     "Headline" : "Наслов",
-    "Organisation" : "Организација",
     "Role" : "Улога",
     "Additional settings" : "Дополнителни параметри",
     "Enter the database name for %s" : "Внесете го името на базата за %s",
     "You cannot use dots in the database name %s" : "Не можеш да користиш точки во името на базата %s",
     "You need to enter details of an existing account." : "Потребно е да внесете детали од постоечката сметка.",
     "Oracle connection could not be established" : "Oracle врската неможе да се воспостави",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не е поддржана и %s нема да работи соодветно на оваа платформа. Користењето е на ваш ризик! ",
     "For the best results, please consider using a GNU/Linux server instead." : "За најдобри резултати, размислете за користење на сервер со GNU/Linux.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Највероватно оваа истанца %s е стартувана на 32-битна PHP средина и open_basedir е конфигурано во php.ini. Ова ќе прави проблеми со датотеки поголеми од 4 GB.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Отстранете го параметарот open_basedir од php.ini или преминете на 64-битна PHP средина.",
@@ -123,22 +126,21 @@ OC.L10N.register(
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "За позадинското споделување %s мора се имплементира интерфејсот OCP\\Share_Backend",
     "Sharing backend %s not found" : "Не е пронајдено позадинско споделување %s",
     "Sharing backend for %s not found" : "Не е пронајдено позадинско споделување за %s.",
-    "%1$s shared »%2$s« with you" : "%1$s сподели »%2$s« со вас",
-    "%1$s shared »%2$s« with you." : "%1$s сподели »%2$s« со вас.",
-    "Click the button below to open it." : "Кликнете на копчето подолу за да ја отворите.",
-    "Open »%s«" : "Отвори »%s«",
+    "%1$s shared %2$s with you" : "%1$s сподели %2$s со вас",
+    "Open %s" : "Отвори %s",
     "%1$s via %2$s" : "%1$s преку %2$s",
-    "%1$s shared »%2$s« with you and wants to add:" : "%1$s ја сподели папката »%2$s« и додаде:",
-    "%1$s shared »%2$s« with you and wants to add" : "%1$s ја сподели папката »%2$s« и додаде",
-    "»%s« added a note to a file shared with you" : "»%s« додаде белешка до датотеката што ја сподели со вас",
+    "%1$s shared %2$s with you and wants to add:" : "%1$s сподели %2$s со вас и сака да додаде:",
+    "%1$s shared %2$s with you and wants to add" : "%1$s сподели %2$s со вас и сака да додаде",
+    "%s added a note to a file shared with you" : "%s додаде белешка до датотеката што ја сподели со вас",
     "Unknown share type" : "Непознат вид на споделување",
     "You are not allowed to share %s" : "Не сте овластени да ја споделите %s",
     "Cannot increase permissions of %s" : "Неможат да се зголемат дозволите на %s",
     "Files cannot be shared with delete permissions" : "Датотеки неможат да бидат споделени со дозвола за бришење",
     "Files cannot be shared with create permissions" : "Датотеки неможат да бидат споделени со дозвола за создавање",
     "Expiration date is in the past" : "Рокот на траење е во минато време",
-    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможе да се постави рок на траење повеќе од 1 ден","Неможе да се постави рок на траење повеќе од %s дена"],
+    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможе да се постави рок на траење повеќе од %n ден","Неможе да се постави рок на траење повеќе од %n дена"],
     "Sharing is only allowed with group members" : "Споделувањето е овозможено само со членови на групата",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Споделувањето %s е неуспешно, бидејќи ова е веќе споделено со сметката  на %s",
     "The requested share does not exist anymore" : "Споделувањето не постои повеќе",
     "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Корисникот не е креиран затоа што максималниот број на корисници е достигнат. Проверете ги вашите известувања за да дознаете повеќе.",
     "Could not find category \"%s\"" : "Не можам да најдам категорија „%s“",
@@ -188,11 +190,10 @@ OC.L10N.register(
     "Nov." : "Ное.",
     "Dec." : "Дек.",
     "A valid password must be provided" : "Мора да се обезбеди валидна лозинка",
+    "Account disabled" : "Сметката е оневозможена",
     "Login canceled by app" : "Најавата е одкажана од апликација",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Апликацијата \"%1$s\" не може да се инсталира затоа што следниве зависности не се исполнети: %2$s",
     "a safe home for all your data" : "безбеден дом за сите ваши податоци",
-    "File is currently busy, please try again later" : "Датотеката моментално е зафатена, обидете се повторно",
-    "Cannot download file" : "Не може да се преземе датотеката",
     "Application is not enabled" : "Апликацијата не е овозможена",
     "Authentication error" : "Грешка во автентикација",
     "Token expired. Please reload page." : "Жетонот е истечен. Ве молам превчитајте ја страницата.",
@@ -200,8 +201,6 @@ OC.L10N.register(
     "Cannot write into \"config\" directory." : "Не може да зе запишува во \"config\" директориумот",
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во config папката. Видете %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Или, доколку претпочитувате config.php да биде само за читање, поставете параметар \"config_is_read_only\" во него. Видете %s",
-    "Cannot write into \"apps\" directory." : "Не може да зе запишува во \"apps\" директориумот",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во папката со апликации или оневозможување на продавницата за апликации во кофигурациската датотека.",
     "Cannot create \"data\" directory." : "Неможе да се креира директориум \"data\"",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во главната папка. Видете %s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Дозволите најчесто се поправаат со давање дозвола на веб серверот за запишување во главната папка. Видете %s",
@@ -212,8 +211,6 @@ OC.L10N.register(
     "Please ask your server administrator to install the module." : "Замолете го сервер администраторот да го инсталира додатокот.",
     "PHP setting \"%s\" is not set to \"%s\"." : "PHP поставката \"%s\" не е поставена до \"%s\".",
     "Adjusting this setting in php.ini will make Nextcloud run again" : "Прилагодувањето на оваа поставка во php.ini ќе направи повторно да работи ",
-    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е поставено на <code>%s</code> очекувана вредност е <code>0</code>.",
-    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За да го поправите ова, поставете вредност за <code>mbstring.func_overload</code> = <code>0</code> во вашата php.ini датотека.",
     "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP поставено да ги поставува во линија внатрешните блокови на документите. Ова ќе ги направи неколку основни апликации недостапни.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Ова е веројатно предизвикано од кеш-меморија/забрзување како што се Zend OPcache или eAccelerator.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP модулот е инсталиран, но сеуште се прикажува како да недостасува?",
@@ -234,36 +231,19 @@ OC.L10N.register(
     "Storage connection error. %s" : "Грешка во конекција до складиштето. %s",
     "Storage is temporarily not available" : "Складиштето моментално не е достапно",
     "Storage connection timeout. %s" : "Поврзувањето со складиштето не успеа. %s",
+    "Images" : "Слики",
+    "Question" : "Прашање",
+    "Confirmation" : "Потврда",
+    "Text" : "Текст",
     "Summary" : "Резиме",
     "Translate" : "Преведи",
     "Generate headline" : "Генерирај заглавие",
-    "Education Edition" : "Едукативно издание",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Најавените корисници мора да бидат администратори, ко-администратори или да имаат специјални дозволи за да пристапат до овие поставки",
-    "Logged in user must be an admin or sub admin" : "Најавениот корисник мора да биде администратор или заменик администратор",
-    "Logged in user must be an admin" : "Најавениот корисник мора да биде администратор",
-    "File name is a reserved word" : "Името на датотеката е резервиран збор",
-    "File name contains at least one invalid character" : "Името на датотеката соджи невалиден карактер",
-    "File name is too long" : "Името на датотеката е премногу долго",
-    "Help" : "Помош",
-    "Users" : "Корисници",
-    "Unknown user" : "Непознат корисник",
-    "Enter the database username and name for %s" : "Внесете го корисничкото име и името на базата за %s",
-    "Enter the database username for %s" : "Внесете го корисничкото име на базата за %s",
-    "MySQL username and/or password not valid" : "Погрешно MySQL корисничко име и/или лозинка",
-    "Oracle username and/or password not valid" : "Oracle корисничкото име и/или лозинката не се валидни",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL корисничкото име и/или лозинка не се валидни",
-    "Set an admin username." : "Постави администраторско корисничко име",
-    "Sharing %s failed, because this item is already shared with user %s" : "Споделувањето на %s е неуспешно, бидејќи истото веќе е споделено со корисникот %s",
-    "The username is already being used" : "Корисничкото име е веќе во употреба",
-    "Could not create user" : "Неможе да се креира корисник",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Само следниве карактери се дозволени во корисничкото име: \"a-z\", \"A-Z\", \"0-9\", празно место и \"_.@-'\"",
-    "A valid username must be provided" : "Мора да се внесе валидно корисничко име ",
-    "Username contains whitespace at the beginning or at the end" : "Корисничкото име содржи празно место на почетокот или на крајот",
-    "Username must not consist of dots only" : "Корисничкото име не смее да се состои само од точки",
-    "Username is invalid because files already exist for this user" : "Невалидно корисничкото име бидејќи веќе постојат датотеки за овој корисник",
-    "User disabled" : "Оневозможен корисник",
-    "Your data directory is readable by other users." : "Вашата папка со податоци може да се чита и од други корисници.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Поставете дозвола на папката 0770, за да неможе да се чита од други корисници.",
-    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Осигурете се дека има датотека наречена \".ocdata\" во главната папка со податоци."
+    "Organisation" : "Организација",
+    "File is currently busy, please try again later" : "Датотеката моментално е зафатена, обидете се повторно",
+    "Cannot download file" : "Не може да се преземе датотеката",
+    "Cannot write into \"apps\" directory." : "Не може да зе запишува во \"apps\" директориумот",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Ова најчесто се поправа со давање дозвола на веб серверот за запишување во папката со апликации или оневозможување на продавницата за апликации во кофигурациската датотека.",
+    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> е поставено на <code>%s</code> очекувана вредност е <code>0</code>.",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "За да го поправите ова, поставете вредност за <code>mbstring.func_overload</code> = <code>0</code> во вашата php.ini датотека."
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
